@@ -1,7 +1,7 @@
 """Helper to the Dataset and Resource classes for handling HDX dates.
 """
 from collections.abc import Iterable
-from datetime import date, datetime
+from datetime import datetime, timezone
 from typing import Dict, List, Optional, Tuple, Union
 
 from hdx.utilities.dateparse import parse_date
@@ -12,17 +12,18 @@ class DateHelper:
     def get_date_info(
         hdx_date: Dict,
         date_format: Optional[str] = None,
-        today: date = datetime.now(),
+        today: datetime = datetime.utcnow(),
     ) -> Dict:
-        """Get date as datetimes and strings in specified format. If no format is supplied, the ISO 8601
-        format is used. Returns a dictionary containing keys startdate (start date as datetime), enddate (end
-        date as datetime), startdate_str (start date as string), enddate_str (end date as string) and ongoing
-        (whether the end date is a rolls forward every day).
+        """Get date as datetimes and strings in specified format. If no format is
+        supplied, the ISO 8601 format is used. Returns a dictionary containing keys
+        startdate (start date as datetime), enddate (end date as datetime),
+        startdate_str (start date as string), enddate_str (end date as string) and
+        ongoing (whether the end date is a rolls forward every day).
 
         Args:
             hdx_date (str): Input date
             date_format (Optional[str]): Date format. None is taken to be ISO 8601. Defaults to None.
-            today (date): Date to use for today. Defaults to datetime.now.
+            today (datetime): Date to use for today. Defaults to datetime.utcnow.
 
         Returns:
             Dict: Dictionary of date information
@@ -35,10 +36,15 @@ class DateHelper:
             startdate = parse_date(dataset_dates[0])
             enddate = dataset_dates[1]
             if enddate == "*":
-                enddate = datetime(today.year, today.month, today.day, 0, 0)
+                enddate = today.replace(
+                    hour=23,
+                    minute=59,
+                    second=59,
+                    tzinfo=timezone.utc,
+                )
                 ongoing = True
             else:
-                enddate = parse_date(enddate)
+                enddate = parse_date(enddate, max_time=True)
                 ongoing = False
             result["startdate"] = startdate
             result["enddate"] = enddate
@@ -58,28 +64,61 @@ class DateHelper:
         startdate: Union[datetime, str],
         enddate: Union[datetime, str, None] = None,
         ongoing: bool = False,
+        ignore_timeinfo: bool = True,
     ) -> str:
-        """Get an HDX date from either datetime.datetime objects or strings with option to set ongoing.
+        """Get an HDX date from either datetime.datetime objects or strings with option
+        to set ongoing.
 
         Args:
             startdate (Union[datetime, str]): Dataset start date
             enddate (Union[datetime, str, None]): Dataset end date. Defaults to None.
             ongoing (bool): True if ongoing, False if not. Defaults to False.
+            ignore_timeinfo (bool): Ignore time and time zone of date. Defaults to True.
 
         Returns:
             str: HDX date
         """
+        if ignore_timeinfo:
+            timezone_handling = 0
+        else:
+            timezone_handling = 3
+
+        def get_date_str(dt, max=False):
+            if ignore_timeinfo:
+                if max:
+                    dt = dt.replace(
+                        hour=23,
+                        minute=59,
+                        second=59,
+                        microsecond=0,
+                        tzinfo=None,
+                    )
+                else:
+                    dt = dt.replace(
+                        hour=0, minute=0, second=0, microsecond=0, tzinfo=None
+                    )
+            else:
+                dt = dt.astimezone(timezone.utc).replace(
+                    microsecond=0, tzinfo=None
+                )
+            return dt.isoformat()
+
         if isinstance(startdate, str):
-            startdate = parse_date(startdate)
-        startdate = startdate.isoformat()
+            startdate = parse_date(
+                startdate, timezone_handling=timezone_handling
+            )
+        startdate = get_date_str(startdate)
         if ongoing:
             enddate = "*"
-        elif not enddate:
-            enddate = startdate
-        if enddate != "*":
-            if isinstance(enddate, str):
-                enddate = parse_date(enddate)
-            enddate = enddate.isoformat()
+        else:
+            if not enddate:
+                enddate = startdate
+            else:
+                if isinstance(enddate, str):
+                    enddate = parse_date(
+                        enddate, timezone_handling=timezone_handling
+                    )
+                enddate = get_date_str(enddate, max=True)
         return f"[{startdate} TO {enddate}]"
 
     @classmethod
@@ -110,6 +149,9 @@ class DateHelper:
             retval = sorted(int(x) for x in list(startyear))
         startyear = retval[0]
         endyear = retval[-1]
-        startdate = datetime(startyear, 1, 1)
-        enddate = datetime(endyear, 12, 31)
-        return cls.get_hdx_date(startdate, enddate), retval
+        startdate = datetime(startyear, 1, 1, tzinfo=timezone.utc)
+        enddate = datetime(endyear, 12, 31, 23, 59, 59, tzinfo=timezone.utc)
+        return (
+            cls.get_hdx_date(startdate, enddate, ignore_timeinfo=False),
+            retval,
+        )
