@@ -4,8 +4,8 @@ from os.path import join
 from typing import Any, Dict, List, Optional
 
 import hdx.data.organization
+from hdx.api.configuration import Configuration
 from hdx.data.hdxobject import HDXObject
-from hdx.hdx_configuration import Configuration
 
 logger = logging.getLogger(__name__)
 
@@ -265,15 +265,18 @@ class User(HDXObject):
         organizations = list()
         if success:
             for organizationdict in result:
-                organization = hdx.data.organization.Organization.read_from_hdx(
+                org = hdx.data.organization.Organization.read_from_hdx(
                     organizationdict["id"]
                 )
-                organizations.append(organization)
+                organizations.append(org)
         return organizations
 
     @classmethod
     def autocomplete(
-        cls, name: str, limit: int = 20, configuration: Optional[Configuration] = None
+        cls,
+        name: str,
+        limit: int = 20,
+        configuration: Optional[Configuration] = None,
     ) -> List:
         """Autocomplete a user name and return matches
 
